/*
 * This file is part of csharp-gentoodotnetinfo - .NET information tool for Gentoo.
 * Copyright (c) 20233-2024, Maciej Barć <xgqt@gentoo.org>
 * Licensed under the GNU GPL v2 License
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * csharp-gentoodotnetinfo is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * csharp-gentoodotnetinfo is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with csharp-gentoodotnetinfo.  If not, see <https://www.gnu.org/licenses/>.
 */

using System;
using System.Globalization;
using System.Runtime.InteropServices;

namespace Gentoo.DotNet.GentooDotnetInfo.Info
{

    public class OperatingSystemInfo
    {

        public String OSProcessArchitecture
        {
            get
            {
                Architecture architecture = RuntimeInformation.ProcessArchitecture;

                return architecture.ToString();
            }
        }

        public String OSProcessorCount
        {
            get
            {
                int processorCount = Environment.ProcessorCount;

                return processorCount.ToString();
            }
        }

        public String OSVersion
        {
            get
            {
                try
                {
                    OperatingSystem osVersion = Environment.OSVersion;

                    return osVersion.ToString();
                }
                catch (Exception)
                {
                    return null;
                }
            }
        }

        public String Locale
        {
            get
            {
                try
                {
                    String cultureName = CultureInfo.CurrentCulture.Name.Trim();

                    // Known cases:
                    //   - LC_ALL=C
                    if (cultureName == "")
                    {
                        return null;
                    }

                    return cultureName;
                }
                catch (Exception)
                {
                    return null;
                }
            }
        }

    }

}
